%define	major		8
%define	libname		%mklibname %{name} %major
%define	develname	%mklibname %{name} -d

%define toolchain clang

Name:           linuxsampler
Summary:        Professional grade software audio sampler
Version:        2.4.0
Release:        %mkrel 3
License:        GPLv2
Group:          Sound/Midi
URL:            https://www.linuxsampler.org/
Source0:        https://download.linuxsampler.org/packages/linuxsampler-%{version}.tar.bz2
Patch0:         linuxsampler-0001-armv7hl-fix.patch
Patch1:         linuxsampler-0002-aarch64-fix.patch
Patch2:         linuxsampler-gcc14-bis.patch
Patch3:         linuxsampler-parallel.patch

BuildRequires:	pkgconfig(gig) >= 4.5.0
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(dssi)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	bison-devel-static
BuildRequires:	doxygen
BuildRequires:	pkgconfig(lv2) >= 1.18.10
BuildRequires:	perl(XML::Parser)
BuildRequires:	flex
%if "%{toolchain}" == "clang"
BuildRequires:  clang
%endif
Requires:       jackit
Requires:       liblscp
Requires:       gig
Requires:       lv2

Conflicts: 	%{mklibname %{name} 7}

%description
LinuxSampler is a free software audio sampler with professional grade
features. It offers disk streaming capability, real-time instrument
scripts, and supports the following three sampler formats:
 - GigaStudio 4, previously known as Gigasampler (.gig)
 - SFZ2 (.sfz)
 - SoundFont 2 (.sf2)

%files
%doc README.urpmi AUTHORS ChangeLog NEWS
%{_bindir}/%{name}
%{_bindir}/lscp*
%{_bindir}/ls_instr_script
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/lscp*.1.*
%{_localstatedir}/lib/%{name}/*.db

#--------------------------------------------------------------------

%package -n %{libname}
Group:		System/Libraries
Summary:	Libraries for %{name}
Provides:	lib%{name} = %{version}-%{release}
Conflicts:	%{_lib}%{name}5 < 2.2.0

%description -n %{libname}
Libraries from %{name}.

%files -n %{libname}
%config %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_libdir}/%{name}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lv2/%{name}.lv2/*.so
%{_libdir}/lv2/%{name}.lv2/*.ttl
%{_libdir}/dssi/*.so
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/lv2/%{name}.lv2

#--------------------------------------------------------------------

%package -n %{develname}
Group:		Development/Other
Summary:	Libraries for %{name}
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Development libraries from %{name}.

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{name}/lib%{name}.so

#--------------------------------------------------------------------

%prep
%setup -q

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

%build
autoreconf -fi
%configure --disable-static
%make_build
make docs

%install
%make_install

# (tv) fix conflicts with nilfs-utils:
mv %{buildroot}%{_bindir}/lscp{,-linuxsampler}
mv %{buildroot}%{_mandir}/man1/lscp{,-linuxsampler}.1

# ld.so.conf.d config for libraries outside the standard search path (mga#28229)
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d/
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf << EOF
%{_libdir}/%{name}/
EOF

cat > README.urpmi <<EOF
WARNING
-------
LinuxSampler is licensed under the GNU GPL with the exception that 
USAGE of the source code, libraries and applications FOR COMMERCIAL 
HARDWARE OR SOFTWARE PRODUCTS IS NOT ALLOWED  without prior written 
permission by the LinuxSampler authors. If you have questions on the 
subject, that are not yet covered by the FAQ, please contact us. 
EOF


%changelog
* Tue Jun 17 2025 philippedidier <philippedidier> 2.4.0-3.mga10
+ Revision: 2192198
- patch added for armv7hl

* Sun Jun 15 2025 pterjan <pterjan> 2.4.0-2.mga10
+ Revision: 2191851
- Fix parallel build
+ philippedidier <philippedidier>
- new version 2.4.0

* Wed Apr 03 2024 philippedidier <philippedidier> 2.3.1-1.mga10
+ Revision: 2054210
- new version 2.3.1 built on gig-4.4.1

* Wed Apr 03 2024 wally <wally> 2.3.0-4.mga10
+ Revision: 2054182
- build using clang toolchain

* Wed Apr 03 2024 wally <wally> 2.3.0-3.mga10
+ Revision: 2054178
- fix build with gcc14

* Sun Jan 28 2024 philippedidier <philippedidier> 2.3.0-2.mga10
+ Revision: 2035573
- restore patch for arm arches
- new version 2.3.0 patch merged upstream no more needed

* Mon Jun 05 2023 philippedidier <philippedidier> 2.2.0-6.mga9
+ Revision: 1960939
- change patch to allow build on aarch64

* Sun Apr 03 2022 umeabot <umeabot> 2.2.0-4.mga9
+ Revision: 1841699
- Mageia 9 Mass Rebuild

* Fri Sep 17 2021 tv <tv> 2.2.0-3.mga9
+ Revision: 1745621
- Fix upgrade from mga8 to mga9
+ barjac <barjac>
- fix conflict

* Thu May 13 2021 barjac <barjac> 2.2.0-2.mga9
+ Revision: 1722781
- exclude aarch64
- add conflict
- test aarch64 build

* Wed May 12 2021 barjac <barjac> 2.2.0-1.mga9
+ Revision: 1722535
- new version 1.2.0
- new major 6
- remove obsolete patch

* Wed Jan 27 2021 wally <wally> 2.1.1-5.mga8
+ Revision: 1673725
- add ld.so.conf.d config for libraries outside the standard search path (mga#28229)

* Wed Jan 27 2021 daviddavid <daviddavid> 2.1.1-4.mga8
+ Revision: 1673705
- move dssi and lv2 files from devel to libraries sub-pkg

* Fri Aug 21 2020 barjac <barjac> 2.1.1-3.mga8
+ Revision: 1617554
- Fix build with upstream patch

* Mon Feb 17 2020 umeabot <umeabot> 2.1.1-2.mga8
+ Revision: 1537383
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Oct 30 2019 barjac <barjac> 2.1.1-1.mga8
+ Revision: 1456861
- new version 2.1.1

* Sun Feb 03 2019 tv <tv> 2.1.0-8.mga7
+ Revision: 1362847
- fix conflicts with nilfs-utils

* Fri Feb 01 2019 tv <tv> 2.1.0-7.mga7
+ Revision: 1362189
- Conflicts nilfs-utils in the short term so that urpmi handles it more nicely

* Thu Jan 31 2019 barjac <barjac> 2.1.0-6.mga7
+ Revision: 1362008
- move some files to lib package from -devel
- as these are needed by pulseeffects at run time

* Sun Sep 23 2018 umeabot <umeabot> 2.1.0-5.mga7
+ Revision: 1299318
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 wally <wally> 2.1.0-4.mga7
+ Revision: 1248707
- skip build on aarch64

* Thu Dec 21 2017 barjac <barjac> 2.1.0-3.mga7
+ Revision: 1183693
- another patch to try to fix arm build

* Thu Dec 21 2017 barjac <barjac> 2.1.0-2.mga7
+ Revision: 1183679
- patch to try to fix arm build

* Thu Dec 21 2017 barjac <barjac> 2.1.0-1.mga7
+ Revision: 1183629
- new version 2.1.0
- new major
- spec clean-up & removed script for snapshots
- fixed SOURCE0 & files list

* Thu Jul 14 2016 pterjan <pterjan> 2.0.0-3.mga6
+ Revision: 1041975
- Make it build on arm

* Sat Feb 20 2016 umeabot <umeabot> 2.0.0-2.mga6
+ Revision: 972036
- Mageia 6 Mass Rebuild

* Sat Oct 24 2015 barjac <barjac> 2.0.0-1.mga6
+ Revision: 894819
- new version 2.0.0

* Sat Aug 29 2015 cjw <cjw> 1.0.0-1.2671.4.mga6
+ Revision: 870996
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 1.0.0-1.2671.3.mga5
+ Revision: 746183
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.0-1.2671.2.mga5
+ Revision: 681954
- Mageia 5 Mass Rebuild

* Tue Sep 02 2014 barjac <barjac> 1.0.0-1.2671.1.mga5
+ Revision: 670969
- new snapshot 2671
- new BR flex
- fix files list

* Tue May 13 2014 barjac <barjac> 1.0.0-1.2546.4.mga5
+ Revision: 622398
- new snapshot 2546
- add buildrequire perl-xml-parser
- use find --delete
- fix files list

* Fri May 09 2014 barjac <barjac> 1.0.0-1.2468.3.mga5
+ Revision: 621660
- rebuild for new lv2

* Sat Oct 19 2013 umeabot <umeabot> 1.0.0-1.2468.2.mga4
+ Revision: 534311
- Mageia 4 Mass Rebuild

* Tue Sep 10 2013 fwang <fwang> 1.0.0-1.2468.1.mga4
+ Revision: 477194
- update to r2468 to build with bison 3.0

* Sun Aug 11 2013 barjac <barjac> 1.0.0-1.2459.1.mga4
+ Revision: 465342
- new snapshot 2459

* Sat Jan 12 2013 umeabot <umeabot> 1.0.0-1.2379.2.mga3
+ Revision: 358862
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 11 2013 barjac <barjac> 1.0.0-1.2379.1.mga3
+ Revision: 348974
- correct release format as interim until version update

* Sat Nov 24 2012 barjac <barjac> 1.0.0-1.2379.mga3
+ Revision: 321650
- rebuild with lv2

* Tue Nov 13 2012 barjac <barjac> 1.0.0-0.2379.mga3
+ Revision: 317563
- spec clean
- new svn snapshot revision
- several new BuildRequires
- removed lv2 pending bug 7639
- several new requires
- removed static libs
- relocated urpmi.README
- added mk_svn_tar script to sources
- thanks to Philippe Didier for his work on this package
- Import from Mandriva

